@@ -4,12 +4,17 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-PKG_NAME="zapping."
+PACKAGE=libzvbi
+ACLOCAL_FLAGS="$ACLOCAL_FLAGS -I m4"
 
-(test -f $srcdir/configure.in) || {
+# automake --copy: no links please (NFS)
+GETTEXTIZE_FLAGS="--copy --no-changelog"
+am_opt="--copy"
+
+(test -f $srcdir/configure.ac) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level directory"
     exit 1
 }
 
-. $srcdir/macros/autogen.sh
+. $srcdir/build-aux/autogen.sh
