@@ -25,7 +25,7 @@
  *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: network.c,v 1.5 2008/02/19 00:51:51 mschimek Exp $ */
+/* $Id: network.c,v 1.8 2013-08-28 14:45:53 mschimek Exp $ */
 
 /* This example shows how to identify a network from data transmitted
    in XDS packets, Teletext packet 8/30 format 1 and 2, and VPS packets.
@@ -79,7 +79,7 @@ handler				(vbi_event *		ev,
 
 	network_name = "unknown";
 	if (0 != ev->ev.network.name[0])
-		network_name = ev->ev.network.name;
+		network_name = (const char *) ev->ev.network.name;
 
 	/* The network name is an ISO-8859-1 string (the API is
 	   quite old...) so we convert it to locale encoding,
@@ -93,10 +93,10 @@ handler				(vbi_event *		ev,
 	/* ASCII. */
 	call_sign = "unknown";
 	if (0 != ev->ev.network.call[0])
-		call_sign = ev->ev.network.call;
+		call_sign = (const char *) ev->ev.network.call;
 
 	printf ("%s: receiving: \"%s\" call sign: \"%s\" "
-	        "CNI VPS: 0x%x 8/30-1: 0x%x 8/30-2: 0x%x\n",
+	        "CNI VPS: 0x%x 8/30/1: 0x%x 8/30/2: 0x%x\n",
 		event_name,
 		(NULL == locale_network_name) ?
 		"iconv-error" : locale_network_name,
@@ -140,11 +140,11 @@ mainloop			(void)
 			fprintf (stderr, "VBI read error %d (%s)\n",
 				 errno, strerror (errno));
 			/* Could be ignored, esp. EIO with some drivers. */
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 
 		case 0: 
 			fprintf (stderr, "VBI read timeout\n");
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 
 		case 1: /* success */
 			break;
@@ -192,7 +192,6 @@ main				(void)
 			 errstr);
 
 		free (errstr);
-		errstr = NULL;
 
 		exit (EXIT_FAILURE);
 	}
@@ -210,10 +209,8 @@ main				(void)
 	mainloop ();
 
 	vbi_decoder_delete (dec);
-	dec = NULL;
 
 	vbi_capture_delete (cap);
-	cap = NULL;
 
 	exit (EXIT_SUCCESS);
 }
