@@ -36,18 +36,28 @@
 #include <string.h>
 #include <stdarg.h>
 #include <sys/types.h>
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <dlfcn.h>
 
-#include "io.h"
+#include "inout.h"
 #include "proxy-msg.h"
 #include "proxy-client.h"
 
 #if !defined (__NetBSD__) && !defined (__FreeBSD__) && !defined (__FreeBSD_kernel__)
-#include "videodev.h"
+#include <asm/types.h> /* __u8 and friends */
+#ifndef HAVE_S64_U64
+#  include <inttypes.h>
+  /* Linux 2.6.x asm/types.h defines __s64 and __u64 only
+     if __GNUC__ is defined. */
+typedef int64_t __s64;
+typedef uint64_t __u64;
+#endif
 #include "videodev2k.h"
+#include "videodev.h"
 # define BASE_VIDIOCPRIVATE      192
 # define BTTV_VERSION            _IOR('v' , BASE_VIDIOCPRIVATE+6, int)
 # define BTTV_VBISIZE            _IOR('v' , BASE_VIDIOCPRIVATE+8, int)
