@@ -19,7 +19,7 @@
  *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: dvb_demux.c,v 1.23 2008/02/19 00:35:15 mschimek Exp $ */
+/* $Id: dvb_demux.c,v 1.25 2013-12-20 16:31:43 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -1346,7 +1346,9 @@ decode_timestamp		(vbi_dvb_demux *	dx,
 	if (mark != (p[0] & 0xF1u)) {
 		debug2 (&dx->frame.log,
 			"Invalid PTS/DTS byte[0]=0x%02x.", p[0]);
-		return FALSE;
+		/* Check disabled to work around invalid mark 0xF1
+		   transmitted instead of 0x21 on Dantoto Racing. */
+		/* return FALSE; */
 	}
 
 	t  = p[1] << 22;
@@ -2368,7 +2370,7 @@ vbi_dvb_demux_cor		(vbi_dvb_demux *	dx,
  * @param buffer_size Number of bytes in @a buffer, need not align with
  *   packet size. The packet filter works faster with larger buffers.
  *
- * This function consumes and arbitrary number of bytes from a DVB
+ * This function consumes an arbitrary number of bytes from a DVB
  * Packetized Elementary Stream (PES), filters
  * out PRIVATE_STREAM_1 PES packets, filters out valid VBI data units,
  * converts them to vbi_sliced format and calls the vbi_dvb_demux_cb
