@@ -1,27 +1,25 @@
 /*
  *  libzvbi - Export modules
  *
- *  Copyright (C) 2001, 2002 Michael H. Schimek
+ *  Copyright (C) 2001, 2002, 2007 Michael H. Schimek
  *
- *  Based on code from AleVT 1.5.1
- *  Copyright (C) 1998, 1999 Edgar Toernig <froese@gmx.de>
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: export.h,v 1.14 2007/11/27 17:42:06 mschimek Exp $ */
+/* $Id: export.h,v 1.18 2008-02-24 14:17:37 mschimek Exp $ */
 
 #ifndef EXPORT_H
 #define EXPORT_H
@@ -271,13 +269,13 @@ vbi_export_mem			(vbi_export *		e,
 				 void *			buffer,
 				 size_t			buffer_size,
 				 const vbi_page *	pg)
-  _vbi_attribute ((_vbi_nonnull (1))); /* sic */
+  _vbi_nonnull ((1)); /* sic */
 extern void *
 vbi_export_alloc		(vbi_export *		e,
 				 void **		buffer,
 				 size_t *		buffer_size,
 				 const vbi_page *	pg)
-  _vbi_attribute ((_vbi_nonnull (1))); /* sic */
+  _vbi_nonnull ((1)); /* sic */
 extern vbi_bool			vbi_export_stdio(vbi_export *, FILE *fp, vbi_page *pg);
 extern vbi_bool			vbi_export_file(vbi_export *, const char *name, vbi_page *pg);
 
@@ -448,7 +446,7 @@ struct vbi_export_class {
 };
 
 /**
- * @example exp-templ.c
+ * @example src/exp-templ.c
  * @ingroup Exmod
  *
  * Template for internal export module.
@@ -463,24 +461,24 @@ struct vbi_export_class {
 extern vbi_bool
 _vbi_export_grow_buffer_space	(vbi_export *		e,
 				 size_t			min_space)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 
 extern vbi_bool
 vbi_export_flush		(vbi_export *		e)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_export_putc			(vbi_export *		e,
 				 int			c)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_export_write		(vbi_export *		e,
 				 const void *		src,
 				 size_t			src_size)
-  _vbi_attribute ((_vbi_nonnull (1, 2)));
+  _vbi_nonnull ((1, 2));
 extern vbi_bool
 vbi_export_puts			(vbi_export *		e,
 				 const char *		src)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_export_puts_iconv		(vbi_export *		e,
 				 const char *		dst_codeset,
@@ -488,25 +486,24 @@ vbi_export_puts_iconv		(vbi_export *		e,
 				 const char *		src,
 				 unsigned long		src_size,
 				 int			repl_char)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_export_puts_iconv_ucs2	(vbi_export *		e,
 				 const char *		dst_codeset,
 				 const uint16_t *	src,
 				 long			src_length,
 				 int			repl_char)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_export_vprintf		(vbi_export *		e,
 				 const char *		templ,
 				 va_list		ap)
-  _vbi_attribute ((_vbi_nonnull (1, 2)));
+  _vbi_nonnull ((1, 2));
 extern vbi_bool
 vbi_export_printf		(vbi_export *		e,
 				 const char *		templ,
 				 ...)
-  _vbi_attribute ((_vbi_nonnull (1, 2),
-		  _vbi_format (printf, 2, 3)));
+  _vbi_nonnull ((1, 2)) _vbi_format ((printf, 2, 3));
 
 /**
  * @addtogroup Exmod
