@@ -28,7 +28,11 @@
 #include <unistd.h>		/* read() */
 #include <errno.h>
 #include <sys/select.h>
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #ifndef HAVE_S64_U64
   /* Linux 2.6.x asm/types.h defines __s64 and __u64 only
@@ -38,7 +42,7 @@ typedef uint64_t __u64;
 #endif
 #include "dvb/dmx.h"
 
-#include "io.h"
+#include "inout.h"
 #include "vbi.h"		/* vbi_init_once */
 #include "dvb_demux.h"
 
@@ -589,7 +593,7 @@ vbi_capture_dvb_new		(char *			dev,
 
 #else /* !ENABLE_DVB */
 
-#include "io.h"
+#include "inout.h"
 #include "vbi.h"
 
 /**
