@@ -27,7 +27,7 @@ static const char rcsid [] =
 #endif
 
 #include "vbi.h"
-#include "io.h"
+#include "inout.h"
 
 #ifdef ENABLE_V4L2
 
@@ -39,7 +39,9 @@ static const char rcsid [] =
 #include <assert.h>
 #include <sys/time.h>		/* timeval */
 #include <sys/types.h>		/* fd_set */
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>		/* for (_)videodev2.h */
+#endif
 #include <asm/types.h>		/* for videodev2.h */
 #include <pthread.h>
 
