@@ -131,12 +131,16 @@
 #include <netdb.h>
 #include <syslog.h>
 #include <assert.h>
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
+#ifdef HAVE_SYS_MMAN_H
 #include <sys/mman.h>
+#endif
 
 #include "bcd.h"
 #include "vbi.h"
-#include "io.h"
+#include "inout.h"
 #include "misc.h"
 #include "proxy-msg.h"
 
