@@ -19,7 +19,7 @@
  *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: raw_decoder.c,v 1.23 2008/02/19 00:35:21 mschimek Exp $ */
+/* $Id: raw_decoder.c,v 1.24 2008-08-19 10:04:46 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -499,6 +499,8 @@ decode_pattern			(vbi3_raw_decoder *	rd,
 
 			/* Positive match, output decoded line. */
 
+			/* FIXME: if we have a field number we should
+			   really only set the service id of one field. */
 			sliced->id = job->id;
 			sliced->line = 0;
 
