@@ -1,41 +1,42 @@
 /*
- *  libzvbi - VBI decoding library
+ *  libzvbi -- VBI decoding library
  *
  *  Copyright (C) 2000, 2001, 2002 Michael H. Schimek
- *  Copyright (C) 2000, 2001 Iaki Garca Etxebarria
+ *  Copyright (C) 2000, 2001 Iñaki García Etxebarria
  *
- *  Based on AleVT 1.5.1
- *  Copyright (C) 1998, 1999 Edgar Toernig <froese@gmx.de>
+ *  Originally based on AleVT 1.5.1 by Edgar Toernig
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: vbi.h,v 1.14 2007/11/27 18:31:07 mschimek Exp $ */
+/* $Id: vbi.h,v 1.17 2009-03-04 21:47:56 mschimek Exp $ */
 
 #ifndef VBI_H
 #define VBI_H
 
 #include <pthread.h>
 
-#include "vt.h"
+#include "teletext_decoder.h"
 #include "cc.h"
 #include "decoder.h"
 #include "event.h"
-#include "cache.h"
+#include "cache-priv.h"
 #include "trigger.h"
 #include "pfc_demux.h"
+#include "pdc.h"
 
 struct event_handler {
 	struct event_handler *	next;
@@ -45,11 +46,6 @@ struct event_handler {
 };
 
 struct vbi_decoder {
-#if 0 // obsolete
-	fifo			*source;
-        pthread_t		mainloop_thread_id;
-	int			quit;		/* XXX */
-#endif
 	double			time;
 
 	pthread_mutex_t		chswcd_mutex;
@@ -69,7 +65,9 @@ struct vbi_decoder {
 	struct teletext		vt;
 	struct caption		cc;
 
-	struct cache		cache;
+	cache_network *		cn;
+
+	vbi_cache *		ca;
 
 	vbi_pfc_demux		epg_pc[2];
 
@@ -85,16 +83,7 @@ struct vbi_decoder {
 	int			wss_rep_ct;
 	double			wss_time;
 
-	/* Property of the vbi_push_video caller */
-#if 0 // obsolete
-	enum tveng_frame_pixformat
-				video_fmt;
-	int			video_width; 
-	double			video_time;
-	vbi_bit_slicer_fn *	wss_slicer_fn;
-	vbi_bit_slicer		wss_slicer;
-	producer		wss_producer;
-#endif
+	vbi_program_id		vps_pid;
 };
 
 #ifndef VBI_DECODER
@@ -155,10 +144,10 @@ typedef enum {
 	VBI_NOW_AND_NEXT = 0x7D,
 	VBI_PROGR_INDEX = 0x7F,
 	VBI_PROGR_SCHEDULE = 0x81,
-	VBI_UNKNOWN_PAGE = 0xFF,
+	VBI_UNKNOWN_PAGE = 0xFF
 /* Private */
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-	VBI_NOT_PUBLIC = 0x80,
+	, VBI_NOT_PUBLIC = 0x80,
 	VBI_CA_DATA_BROADCAST =	0xE0,
 	VBI_EPG_DATA = 0xE3,
 	VBI_SYSTEM_PAGE = 0xE7,
