@@ -19,16 +19,13 @@
  *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: vps.h,v 1.7 2008/02/24 14:16:53 mschimek Exp $ */
+/* $Id: vps.h,v 1.9 2009-03-04 21:48:35 mschimek Exp $ */
 
 #ifndef __ZVBI_VPS_H__
 #define __ZVBI_VPS_H__
 
 #include <inttypes.h>		/* uint8_t */
 #include "macros.h"
-#ifndef ZAPPING8
-#  include "version.h"
-#endif
 #include "pdc.h"		/* vbi_program_id */
 
 VBI_BEGIN_DECLS
@@ -50,10 +47,6 @@ extern vbi_bool
 vbi_encode_vps_cni		(uint8_t		buffer[13],
 				 unsigned int		cni)
   _vbi_nonnull ((1));
-
-/* Private */
-
-#if defined ZAPPING8 || 3 == VBI_VERSION_MINOR
 extern vbi_bool
 vbi_decode_vps_pdc		(vbi_program_id *	pid,
 				 const uint8_t		buffer[13])
@@ -63,7 +56,7 @@ vbi_decode_vps_pdc		(vbi_program_id *	pid,
   ;
 extern vbi_bool
 vbi_encode_vps_pdc		(uint8_t		buffer[13],
-				 const vbi_program_id *pid)
+				 const vbi_program_id *	pid)
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
   _vbi_nonnull ((1, 2))
 #endif
@@ -77,14 +70,16 @@ vbi_decode_dvb_pdc_descriptor	(vbi_program_id *	pid,
   ;
 vbi_bool
 vbi_encode_dvb_pdc_descriptor	(uint8_t		buffer[5],
-				 const vbi_program_id *pid)
+				 const vbi_program_id *	pid)
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
   _vbi_nonnull ((1, 2))
 #endif
   ;
-#endif
+
 /** @} */
 
+/* Private */
+
 VBI_END_DECLS
 
 #endif /* __ZVBI_VPS_H__ */
