@@ -15,13 +15,16 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
-/* $Id: sliced2pes.c,v 1.13 2007/11/27 17:54:38 mschimek Exp $ */
+/* $Id: sliced2pes.c,v 1.15 2008-03-01 07:36:24 mschimek Exp $ */
 
 /* For libzvbi version 0.2.x / 0.3.x. */
 
+#undef NDEBUG
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
