@@ -15,13 +15,18 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
-/* $Id: test-dvb_mux.cc,v 1.4 2007/10/14 14:53:54 mschimek Exp $ */
+/* $Id: test-dvb_mux.cc,v 1.7 2017-03-18 15:08:55 mschimek Exp $ */
 
 #undef NDEBUG
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <assert.h>
 #include <stdlib.h>
 #include <string.h>
@@ -132,7 +137,7 @@ is_good_service			(vbi_service_set	service)
 static const vbi_service_set
 all_services [] = {
 	0,
-	-1,
+	(vbi_service_set) -1,
 	VBI_SLICED_2xCAPTION_525,
 	VBI_SLICED_CAPTION_525,
 	VBI_SLICED_CAPTION_525_F1,
@@ -3232,7 +3237,7 @@ static void
 test_dvb_mux_cor_pts (void)
 {
 	static const int64_t ptss [] = {
-		0x8000000000000000ll, -1, 0, 0x7FFFFFFFFFFFFFFFll,
+		(int64_t) 0x8000000000000000ll, -1, 0, 0x7FFFFFFFFFFFFFFFll,
 	};
 	DVBPESMuxTest mx;
 	unsigned int i;
