@@ -34,7 +34,7 @@
 #include "src/misc.h"
 
 static void
-putwchar			(unsigned int		c)
+putwchar_local			(unsigned int		c)
 {
 	if (c < 0x80) {
 		putchar (c);
@@ -53,6 +53,9 @@ putwchar			(unsigned int		c)
 	}
 }
 
+#undef putwchar
+#define putwchar putwchar_local
+
 static void
 putwstr				(const char *		s)
 {
